builder library
Functions
-
mockBuilder(
BuilderOptions options) → Builder -
Returns the
Builderregistered inbuild.yaml. Emits a.mock.g.dartpart-file next to every input library that contains at least one class annotated with@Mockable().
Builder registered in build.yaml. Emits a .mock.g.dart
part-file next to every input library that contains at least one class
annotated with @Mockable().